@@ -8,7 +8,7 @@ use FabForce::DBDesigner4;
 
 # ABSTRACT: create DBIC scheme for DBDesigner4 xml file
 
-our $VERSION = '0.09';
+our $VERSION = '0.11';
 
 
 sub new {
@@ -22,6 +22,11 @@ sub new {
     $self->namespace( $args{namespace} );
     $self->schema_name( $args{schema_name} );
     $self->version_add( $args{version_add} );
+    $self->column_details( $args{column_details} );
+
+    if ( $args{use_fake_dbic} ) {
+        require FabForce::DBDesigner4::DBIC::FakeDBIC;
+    }
     
     $self->prefix( 
         'belongs_to'   => '',
@@ -51,6 +56,14 @@ sub input_file{
 }
 
 
+sub column_details {
+    my ($self,$bool) = @_;
+    
+    $self->{_column_details} = $bool if defined $bool;
+    return $self->{_column_details};
+}
+
+
 sub version_add{
     my ($self,$inc) = @_;
     
@@ -291,8 +304,41 @@ sub _class_template{
     }
     
     my @columns = $table->column_names;
-    my $column_string = join "\n", map{ "    " . $_ }@columns;
-    
+    my $column_string = '';
+
+    if ( !$self->column_details ) {
+        $column_string = "qw/\n" . join "\n", map{ "    " . $_ }@columns, "    /";
+    }
+    else {
+        my @columns = @{ $table->column_details || [] };
+
+        for my $column ( @columns ) {
+            $column->{DefaultValue} =~ s/'/\\'/g;
+
+            if ( $column->{DataType} =~ /char/i && $column->{Width} <= 0 ) {
+                $column->{Width} = 255;
+            }
+
+            my @options;
+
+            my $name          = $column->{ColName};
+
+            push @options, "data_type => '" . $column->{DataType} . "',";
+            push @options, "is_auto_increment => 1,"                             if $column->{AutoInc};
+            push @options, "is_nullable => 1,"                                   if !$column->{NotNull};
+            push @options, "size => " . $column->{Width} . ","                   if $column->{Width} > 0; 
+            push @options, "default_value => '" . $column->{DefaultValue} . "'," if $column->{DefaultValue};
+
+            my $option_string = join "\n        ", @options;
+
+            $column_string .= <<"            COLUMN";
+    $name => {
+        $option_string
+    },
+            COLUMN
+        }
+    }
+
     my $primary_key   = join " ", $table->key;
     my $version       = $self->_version;
     
@@ -306,9 +352,9 @@ our \$VERSION = $version;
 
 __PACKAGE__->load_components( qw/PK::Auto Core/ );
 __PACKAGE__->table( '$name' );
-__PACKAGE__->add_columns( qw/
+__PACKAGE__->add_columns(
 $column_string
-/);
+);
 __PACKAGE__->set_primary_key( qw/ $primary_key / );
 
 $has_many
@@ -374,6 +420,7 @@ __PACKAGE__->load_namespaces;
 1; # End of FabForce::DBDesigner4::DBIC
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -382,7 +429,7 @@ FabForce::DBDesigner4::DBIC - create DBIC scheme for DBDesigner4 xml file
 
 =head1 VERSION
 
-version 0.09
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -405,9 +452,15 @@ to new (all parameters are optional)
     output_path => '/path/to/dir',
     input_file  => '/path/to/dbdesigner.file',
     namespace   => 'MyApp::Database',
+    version_add => 0.001,
     schema_name => 'MySchema',
+    column_details => 1,
+    use_fake_dbic  => 1, # default 0.
   );
 
+C<use_fake_dbic> is helpful when C<DBIx::Class> is not installed on the
+machine where you use this module.
+
 =head2 output_path
 
 sets / gets the output path for the scheme
@@ -422,6 +475,43 @@ sets / gets the name of the DBDesigner file (XML format)
   $foo->input_file( 'dbdesigner.xml' );
   print $foo->input_file;
 
+=head2 column_details
+
+If enabled, the column definitions are more detailed. Default: disabled.
+
+  $foo->column_details( 1 );
+
+Standard (excerpt from Result classes):
+
+  __PACKAGE__->add_columns( qw/
+    cert_id
+    register_nr
+    state
+  );
+
+With enabled column details:
+
+  __PACKAGE__->add_columns(
+    cert_id => {
+      data_type         => 'integer',
+      is_nullable       => 0,
+      is_auto_increment => 1,
+    },
+    register_nr => {
+      data_type   => 'integer',
+      is_nullable => 0,
+    },
+    state => {
+      data_type     => 'varchar',
+      size          => 1,
+      is_nullable   => 0,
+      default_value => 'done',
+    },
+  );
+
+This is useful when you use L<DBIx::Class::DeploymentHandler> to deploy the columns
+correctly.
+
 =head2 version_add
 
 The files should be versioned (e.g. to deploy the DB via C<DBIx::Class::DeploymentHandler>). On the first run 
@@ -534,4 +624,3 @@ This is free software, licensed under:
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
